Trait radn::rcore::Context

source ·
pub trait Context<'a>: FallibleCtx<'a> + MonadContext<'a> + Send + Sync {
    type D: Diagnostic<'a, Self::T>;
    type LookupError: 'a + Send + Error + From<SingularError>;

    // Required method
    fn hash(s: &[u8]) -> Hash;
}
Execution context.

Required Associated Types

source

type D: Diagnostic<'a, Self::T>

source

type LookupError: 'a + Send + Error + From<SingularError>

Type to represent resolution errors mainly arising in Resolver::resolve.

Required Methods

source

fn hash(s: &[u8]) -> Hash

Get Hash of a slice, mostly for use in Point.

Implementors