Trait radn::rcore::Diagnostic

source ·
pub trait Diagnostic<'a, T: Monad<'a>>: 'a + Send {
    // Required methods
    fn after<'b, A: 'a + Send>(
        fa: T::F<A>,
        event: impl 'b + FnOnce() -> String
    ) -> T::F<A>
       where 'a: 'b;
    fn before<'b, A: 'a + Send>(
        fa: T::F<A>,
        event: impl 'b + FnOnce() -> String
    ) -> T::F<A>
       where 'a: 'b;
    fn wrapped<'b, A: 'a + Send>(
        fa: T::F<A>,
        event: impl 'b + FnOnce() -> String
    ) -> T::F<A>
       where 'a: 'b;
}
Basic support for tracing events across the execution.

Required Methods

source

fn after<'b, A: 'a + Send>( fa: T::F<A>, event: impl 'b + FnOnce() -> String ) -> T::F<A>where 'a: 'b,

Specify that the evaluation happens after a specific event.

source

fn before<'b, A: 'a + Send>( fa: T::F<A>, event: impl 'b + FnOnce() -> String ) -> T::F<A>where 'a: 'b,

Specify that the evaluation happens before a specific event.

source

fn wrapped<'b, A: 'a + Send>( fa: T::F<A>, event: impl 'b + FnOnce() -> String ) -> T::F<A>where 'a: 'b,

Label the evaluation step as a specific named action.

Implementors