Type Definition radn::rcore::HashResolution
source · pub type HashResolution<'a, Ctx> = Wrapped<'a, Ctx, HashResolutionResult<'a, Ctx>>;Expand description
Shorthand for the type of values returned by Resolver::resolve.
pub type HashResolution<'a, Ctx> = Wrapped<'a, Ctx, HashResolutionResult<'a, Ctx>>;Shorthand for the type of values returned by Resolver::resolve.