Type Definition radn::rcore::ParseResult
source · pub type ParseResult<'a, F> = Result<Mtbl<'a, F>, ParseError<'a, F>>;Expand description
Shorthand for the type of values returned by FactoryParse::deserialize.
pub type ParseResult<'a, F> = Result<Mtbl<'a, F>, ParseError<'a, F>>;Shorthand for the type of values returned by FactoryParse::deserialize.