Trait radn::rstd::inlining::static_pair::StaticPairAtomic
source · pub trait StaticPairAtomic: 'static + Send + Sync + Clone + Sized + StaticPairSerializable<SA = Self::A, SB = Self::B> {
type A: AtomicBase + ParseMode;
type B: AtomicBase + ParseMode;
type AParseError: Error + Send;
// Required methods
fn from_parsed(a: Self::A, b: Self::B) -> Result<Self, Self::AParseError>;
fn from_error_a(error: AParseError<Self::A>) -> Self::AParseError;
fn from_error_b(error: AParseError<Self::B>) -> Self::AParseError;
}Expand description
Atomic equivalent of StaticPair.
Note: StaticPairAtomic::A requires InliningAtomic be implemented.
Required Associated Types
sourcetype A: AtomicBase + ParseMode
type A: AtomicBase + ParseMode
First element’s type. Must equal StaticPairSerializable::SA.
sourcetype B: AtomicBase + ParseMode
type B: AtomicBase + ParseMode
Second element’s type. Must equal StaticPairSerializable::SB.
type AParseError: Error + Send
Required Methods
sourcefn from_parsed(a: Self::A, b: Self::B) -> Result<Self, Self::AParseError>
fn from_parsed(a: Self::A, b: Self::B) -> Result<Self, Self::AParseError>
Construct the atomic from the elements.
sourcefn from_error_a(error: AParseError<Self::A>) -> Self::AParseError
fn from_error_a(error: AParseError<Self::A>) -> Self::AParseError
Regularise the error returned while parsing the first element.
sourcefn from_error_b(error: AParseError<Self::B>) -> Self::AParseError
fn from_error_b(error: AParseError<Self::B>) -> Self::AParseError
Regularise the error returned while parsing the second element.