Type Definition radn::rstd::tracing::Traced

source ·
pub type Traced<A> = WithEffect<A, TraceBox>;
Wrapper containing the value and the corresponding execution trace.

For what the trace contains, see its rendered form, RenderedAny.

Implementations

source

impl<A> Traced<A>

source

impl<A> Traced<A>

source

pub fn after_resolution(self) -> Self

source

pub fn length(&self) -> usize

source

pub fn width(&self) -> usize