pub type Traced<A> = WithEffect<A, TraceBox>;Expand description
Wrapper containing the value and the corresponding execution trace.
For what the trace contains, see its rendered form, RenderedAny.
pub type Traced<A> = WithEffect<A, TraceBox>;Wrapper containing the value and the corresponding execution trace.
For what the trace contains, see its rendered form, RenderedAny.